==> haskell-tasty-hunit-0.10.1-36.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hunit
version:              0.10.1
visibility:           public
id:                   tasty-hunit-0.10.1-4ZLXzmig7dB7SIf0frrz0O
key:                  tasty-hunit-0.10.1-4ZLXzmig7dB7SIf0frrz0O
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  2fca2ae2509b7ee0394f38825335337b
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.1-4ZLXzmig7dB7SIf0frrz0O
depends:
    base-4.16.4.0 call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    tasty-1.4.3-45V6IUrFvI6FX8Qf0XPHba

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.1-40.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hunit
version:              0.10.1
visibility:           public
id:                   tasty-hunit-0.10.1-4ZYp83MGxX28IFU2SfTwqM
key:                  tasty-hunit-0.10.1-4ZYp83MGxX28IFU2SfTwqM
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.

    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.

category:             Testing
abi:                  bcd704f56fbbcbe5cd8d9254975609e4
exposed:              True
exposed-modules:      Test.Tasty.HUnit
hidden-modules:       Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-hunit-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hunit
hs-libraries:         HStasty-hunit-0.10.1-4ZYp83MGxX28IFU2SfTwqM
depends:
    base-4.16.4.0 call-stack-0.4.0-kYtciisYfe7TdjBJDTvHP
    tasty-1.4.3-2gR9WDhWbJHGLAofnQHAx7

haddock-interfaces:   /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
